// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=3dfb15494099434eacf19f0d0fa5a6004253e453$
//

#ifndef CEF_LIBCEF_DLL_CTOCPP_V8_BACKING_STORE_CTOCPP_H_
#define CEF_LIBCEF_DLL_CTOCPP_V8_BACKING_STORE_CTOCPP_H_
#pragma once

#if !defined(WRAPPING_CEF_SHARED)
#error This file can be included wrapper-side only
#endif

#include "include/capi/cef_v8_capi.h"
#include "include/cef_v8.h"
#include "libcef_dll/ctocpp/ctocpp_ref_counted.h"

#if CEF_API_ADDED(14600)

// Wrap a C structure with a C++ class.
// This class may be instantiated and accessed wrapper-side only.
class CefV8BackingStoreCToCpp
    : public CefCToCppRefCounted<CefV8BackingStoreCToCpp, CefV8BackingStore,
                                 cef_v8_backing_store_t> {
public:
  CefV8BackingStoreCToCpp();
  virtual ~CefV8BackingStoreCToCpp();

  // CefV8BackingStore methods.
  void *Data() override;
  size_t ByteLength() override;
  bool IsValid() override;
};

constexpr auto CefV8BackingStoreCToCpp_Wrap = CefV8BackingStoreCToCpp::Wrap;
constexpr auto CefV8BackingStoreCToCpp_Unwrap = CefV8BackingStoreCToCpp::Unwrap;

#endif // CEF_API_ADDED(14600)

#endif // CEF_LIBCEF_DLL_CTOCPP_V8_BACKING_STORE_CTOCPP_H_
