// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=ff7bbaf7ff322455c8b3bf52a497c11377753cd7$
//

#ifndef CEF_LIBCEF_DLL_CTOCPP_V8_STACK_TRACE_CTOCPP_H_
#define CEF_LIBCEF_DLL_CTOCPP_V8_STACK_TRACE_CTOCPP_H_
#pragma once

#if !defined(WRAPPING_CEF_SHARED)
#error This file can be included wrapper-side only
#endif

#include "include/capi/cef_v8_capi.h"
#include "include/cef_v8.h"
#include "libcef_dll/ctocpp/ctocpp_ref_counted.h"

// Wrap a C structure with a C++ class.
// This class may be instantiated and accessed wrapper-side only.
class CefV8StackTraceCToCpp
    : public CefCToCppRefCounted<CefV8StackTraceCToCpp, CefV8StackTrace,
                                 cef_v8_stack_trace_t> {
public:
  CefV8StackTraceCToCpp();
  virtual ~CefV8StackTraceCToCpp();

  // CefV8StackTrace methods.
  bool IsValid() override;
  int GetFrameCount() override;
  CefRefPtr<CefV8StackFrame> GetFrame(int index) override;
};

constexpr auto CefV8StackTraceCToCpp_Wrap = CefV8StackTraceCToCpp::Wrap;
constexpr auto CefV8StackTraceCToCpp_Unwrap = CefV8StackTraceCToCpp::Unwrap;

#endif // CEF_LIBCEF_DLL_CTOCPP_V8_STACK_TRACE_CTOCPP_H_
